* This Do-File replicates the results from the study
* "Beauty contest revisited  the effects of perceived attractiveness, competence and likability on the electoral success of German MPs"
* authors: Sebastian Jckle and Thomas Metz 
* published in Politics and Policy, Vol. 45, No. 4.

* This Do-File consists of three sections:
	* A) Figures and Tables from the Paper
	* B) Further statistics reported in the paper
	* C) Figures and Tables from the Online Appendix
	
* In order to use it, all data-files (*csv) should be saved in the folder "BeautyContestRevisited" and you must set the path accordingly to that folder: 
  cd "[CHANGE TO YOUR PATH]\BeautyContestRevisited"

	version 11	
	clear all
	set matsize 11000
 
***********************************************
***********************************************
**											 **
**	 A) Figures and Tables from the Paper	 **
**											 **
***********************************************
***********************************************
 
*************************
*		Figure 2		*	
*************************

*Read data 
	insheet using "for_logit.csv", delimiter(",")			

set more off
ssc install coefplot, replace
ssc install estout, replace
ssc install outreg2, replace

* generate dummies + labels 
tab(buttons), gen(button_)

tab(type), gen(type_)
label var type_1  "Frau vs. Frau"
label var type_2  "Mann vs. Mann"
label var type_3  "Frau vor Mann"
label var type_4  "Mann vor Frau"

label define trait 1 "Sympathie" 2 "Kompetenz" 3 "Attraktivitt"
label values trait trait

* Alter in Jahrzehnten
gen alter10 = alter/10

tab clicked buttons if trait ==1, chi2 cchi2 V 

*eindeutige ID pro Rater generieren 
gen id_zusammen = id
replace id_zusammen = id + 1000 if freiburg ==0

* Neue Variable generieren, die den Typ des Wahlkreises angibt 0 = Frau vs Frau, 1 = Mann vs Mann, 2 = Frau vs. Mann
	gen type3 = type_d
	replace type3 = 2 if type_d ==3
	label define type3 0 "Frau vs. Frau" 1 "Mann vs. Mann" 2 "Frau vs. Mann"
	lab val type3 type3
	
* type3 als dummies
tab (type3), gen(type3_) 

* gen Rater-dummies
tab id_zusammen, gen(rater_)

gen kurzhaar_x_sex = 0
replace kurzhaar_x_sex = 1 if kurzhaarfrisur == 1 & sex_cand == 0

* Freiburg + Passau:  male and female raters together
	
	** Modellschtzung 1.1 Haupteffektemodell  Frau vs Frau
	quietly eststo m11a: logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 1  & type3_1 == 1
	quietly eststo m11b: logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 2  & type3_1 == 1
	quietly eststo m11c:logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 3  & type3_1 == 1
	
	**Modellschtzung 1.2 Haupteffektemodell  Mann vs Mann
	quietly eststo m12a: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 1  & type3_2 == 1
	quietly eststo m12b: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 2  & type3_2 == 1
	quietly eststo m12c: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 3  & type3_2 == 1
	
	**Modellschtzung 1.3 Haupteffektemodell  Frau vs Mann
	quietly eststo m13a: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 1  & type3_3 == 1
	quietly eststo m13b: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 2  & type3_3 == 1
	quietly eststo m13c: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 3  & type3_3 == 1
			
	coefplot(m11c,label(Attraktivitt) msymbol(d) mcolor(black))(m11b,label(Kompetenz) msymbol (circle_hollow) mcolor(gs12)) ///
	(m11a,label(Sympathie) msymbol(X) mcolor(gs7)) ,  bylabel("Female vs. Female") ///
	||m12c m12b m12a,bylabel( "Male vs. Male")||m13c m13b m13a,bylabel("Female vs. Male") ///
	||,  eform xline(1, lcolor(black) lpattern(dot)) xtitle(Odds Ratio with 99% CIs) byopts(xrescale row(1))  ///
	ylab( ,labs (small) ) lev(99) drop(_cons) omitted baselevels coeflab(alter10="Age (in decades)" brille="Glasses" /// 
	anzug="Suit or Blazer" schmuck="Jewelry" kurzhaar_x_sex="Short hairstyle for women" krawatte ="Tie" glatze="Bald head" ///
	bart="Beard" sex_candidate="Sex (M = 1, F = 0)") grid(none) ciopts(lwidth(thin) lcolor(*.6)) legend(row(1))

graph save figure_2, replace  


*************************
*		Table 1			*	
*************************
clear all

insheet using "main_model_data.csv", delimiter(",")

replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */
gen percent_pop_male = 100*(pop_male/pop)

*model 1
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1
vif /* max 5.15*/
hettest /*.07 -->  heteroscedasticity --> robust standard errors*/
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1, robust
est store main_model1
predict r, resid
swilk r
kdensity r, normal
drop r

*model 2
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1
est store main_model2
vif /* max 5.13*/
hettest /* .42 --> no heterosceadasticity */
predict r, resid
qnorm r
sktest r
swilk r
kdensity r, normal
drop r

*model 3
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1
vif /*max 1.19 */
hettest /*.0288 --> heteroscedasticity --> robust standard errors*/
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1, robust
est store stepwise1
vif
predict r, resid
sktest r
kdensity r, normal
drop r

*model 4
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1
est store stepwise2
vif /*max 1.62 */
hettest /*.2033 --> no heteroscedasticity*/
predict r, resid
qnorm r
swilk r
sktest r
kdensity r, normal
drop r

outreg2 [main_model1 stepwise1 main_model2 stepwise2] using table_1, word replace


*************************
*		Figure 3		*	
*************************
* the plots in figure 3 were made with Excel. The underlying data comes from the lincom command below. 

clear all

insheet using "main_model_data.csv", delimiter(",")

replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */
gen percent_pop_male = 100*(pop_male/pop)

* Figure 3a) Interaction incumbency_BT x attractiveness
	gen incumbency_BT1_attr = incumbency2009_cand1 * fp_attractiveness_w
	gen incumbency_BT2_attr = incumbency2009_cand2 * fp_attractiveness_w
	gen incumbency_BTnone_attr = incumbency2009_none * fp_attractiveness_w
	gen incumbency_BTboth_attr = incumbency2009_both * fp_attractiveness_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  incumbency_BT2_attr incumbency_BTnone_attr incumbency_BTboth_attr businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	
	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.00*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.25*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.50*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*0.75*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BT2_attr*1.00*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 

	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.00*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.25*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.50*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*0.75*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTnone_attr*1.00*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 

	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.00*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.25 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.25*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.50 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.50*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*0.75 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*0.75*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*1.00 + fp_competence_w*.5316212 + fp_likability_w*.5092735 + incumbency_BTboth_attr*1.00*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 

* Figure 3b) Interaction incumbency_BT x likability
	gen incumbency_BT1_lika = incumbency2009_cand1 * fp_likability_w
	gen incumbency_BT2_lika = incumbency2009_cand2 * fp_likability_w
	gen incumbency_BTnone_lika = incumbency2009_none * fp_likability_w
	gen incumbency_BTboth_lika = incumbency2009_both * fp_likability_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  incumbency_BT2_lika incumbency_BTnone_lika incumbency_BTboth_lika businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BT2_lika*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BT2_lika*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BT2_lika*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BT2_lika*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BT2_lika*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BT2_lika*0.00*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BT2_lika*0.25*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BT2_lika*0.50*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BT2_lika*0.75*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BT2_lika*1.00*1 + incumbency2009_cand2*1 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 

	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BTnone_lika*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BTnone_lika*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BTnone_lika*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BTnone_lika*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BTnone_lika*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BTnone_lika*0.00*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BTnone_lika*0.25*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BTnone_lika*0.50*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BTnone_lika*0.75*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BTnone_lika*1.00*1 + incumbency2009_cand2*0 + incumbency2009_none*1 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 

	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BTboth_lika*0.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BTboth_lika*0.25*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BTboth_lika*0.50*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BTboth_lika*0.75*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BTboth_lika*1.00*0 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*0 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + incumbency_BTboth_lika*0.00*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + incumbency_BTboth_lika*0.25*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + incumbency_BTboth_lika*0.50*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + incumbency_BTboth_lika*0.75*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + incumbency_BTboth_lika*1.00*1 + incumbency2009_cand2*0 + incumbency2009_none*0 + incumbency2009_both*1 +woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 


*************************
*		Figure 4		*	
*************************
* the plot in figure 4 was made with Excel. The underlying data comes from the lincom command below. 

clear all

insheet using "main_model_data.csv", delimiter(",")

replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */
gen percent_pop_male = 100*(pop_male/pop)
	
* Interactions likability x gender 
	gen man_man_lika = man_vs_man * fp_likability_w
	gen woman_woman_lika = woman_vs_woman * fp_likability_w
	gen man_woman_lika = man_vs_woman * fp_likability_w
	gen woman_man_lika = woman_vs_man * fp_likability_w

	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  woman_woman_lika  man_woman_lika woman_man_lika businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
		
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + woman_woman_lika*0.00*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + woman_woman_lika*0.25*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + woman_woman_lika*0.50*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + woman_woman_lika*0.75*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + woman_woman_lika*1.00*0 + woman_vs_woman*0 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + woman_woman_lika*0.00*1 + woman_vs_woman*1 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + woman_woman_lika*0.25*1 + woman_vs_woman*1 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + woman_woman_lika*0.50*1 + woman_vs_woman*1 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + woman_woman_lika*0.75*1 + woman_vs_woman*1 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + woman_woman_lika*1.00*1 + woman_vs_woman*1 + woman_vs_man*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0

	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + man_woman_lika*0.00*0 + man_vs_woman*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + man_woman_lika*0.25*0 + man_vs_woman*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + man_woman_lika*0.50*0 + man_vs_woman*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + man_woman_lika*0.75*0 + man_vs_woman*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + man_woman_lika*1.00*0 + man_vs_woman*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + man_woman_lika*0.00*1 + man_vs_woman*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + man_woman_lika*0.25*1 + man_vs_woman*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + man_woman_lika*0.50*1 + man_vs_woman*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + man_woman_lika*0.75*1 + man_vs_woman*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + man_woman_lika*1.00*1 + man_vs_woman*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + woman_man_lika*0.00*0 + woman_vs_man*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + woman_man_lika*0.25*0 + woman_vs_man*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + woman_man_lika*0.50*0 + woman_vs_man*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + woman_man_lika*0.75*0 + woman_vs_man*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + woman_man_lika*1.00*0 + woman_vs_man*0 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.00 + woman_man_lika*0.00*1 + woman_vs_man*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.25 + woman_man_lika*0.25*1 + woman_vs_man*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.50 + woman_man_lika*0.50*1 + woman_vs_man*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*0.75 + woman_man_lika*0.75*1 + woman_vs_man*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	lincom _cons + fp_attractiveness_w*.5001187 + fp_competence_w*.5316212 + fp_likability_w*1.00 + woman_man_lika*1.00*1 + woman_vs_man*1 + woman_vs_woman*0 + man_vs_woman*0 + businesstax*.4787069 + business_reg*1.195367 + turnout*71.37799 + percent_pop_male*49.17924 + senior_youth*1.128477 + unemployed*6.76332 + age_dif*-.3976834 + doctor*0 + contested*1 + secondvote2013_dif*16.15895 + incumbency2009_none*0 + incumbency2009_cand2*0 + incumbency2009_both*0
	

*************************
*		Figure 5		*	
*************************	
clear all

insheet using "main_model_data.csv", delimiter(",")

replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */
gen percent_pop_male = 100*(pop_male/pop)
	
	gen age_attr = age_dif * fp_attractiveness_w
	gen age_comp = age_dif * fp_competence_w
	gen age_lika = age_dif * fp_likability_w

	* Interaction Age x Attractiveness
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w  fp_likability_w age_attr  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
		
		* Marginale Effekte Plot
	
		#delimit ;

		*     ****************************************************************  *;
		*       Generate the values of Z for which you want to calculate the    *;
		*       marginal effect (and standard errors) of X on Y.                *;
		*     ****************************************************************  *;

		generate MV=((_n-33)/1);
		replace  MV=. if _n>65;

		*     ****************************************************************  *;
		*       Grab elements of the coefficient and variance-covariance matrix *;
		*       that are required to calculate the marginal effect and standard *;
		*       errors.                                                         *;
		*     ****************************************************************  *;
		#delimit ;
		reg firstvote2013_dif fp_attractiveness_w age_dif  age_attr fp_competence_w  fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed  doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2  incumbency2009_none incumbency2009_both if filter ==1;

		matrix b=e(b);
		matrix V=e(V);
 
		scalar b1=b[1,1];
		scalar b2=b[1,2];
		scalar b3=b[1,3];


		scalar varb1=V[1,1];
		scalar varb2=V[2,2];
		scalar varb3=V[3,3];

		scalar covb1b3=V[1,3]; 
		scalar covb2b3=V[2,3];

		scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;



		*     ****************************************************************  *
		*       Calculate the marginal effect of X on Y for all MV values of    *
		*       the modifying variable Z.                                       *
		*     ****************************************************************  *

		#delimit ;
		gen conb=b1+b3*MV if _n<65;


		*     ****************************************************************  *
		*       Calculate the standard errors for the marginal effect of X on Y *
		*       for all MV values of the modifying variable Z.                  *
		*     ****************************************************************  *

		#delimit ;
		gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<65;


		*     ****************************************************************  *
		*       Generate upper and lower bounds of the confidence interval.     *
		*       Specify the significance of the confidence interval.            *
		*     ****************************************************************  *
		#delimit ;

		gen a=1.96*conse;
 
		gen upper=conb+a;
 
		gen lower=conb-a;


		#delimit ;

		*     ****************************************************************  *;
		*       Graph the marginal effect of X on Y across the desired range of *;
		*       the modifying variable Z.  Show the confidence interval.        *;
		*     ****************************************************************  *;

		graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        
             yscale(noline)
             xscale(noline)
             legend(col(1) order(1 2) label(1 "marginal effect attractiveness") 
                                      label(2 "95% ci") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             title("a) Attractiveness", size(4))
             /*subtitle(" " "dependent variable: firstvote difference" " ", size(3))*/
             xtitle( "Age difference" "(winners age minus age of runner up)", size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("marginal effect", size(3))
             scheme(s2mono) graphregion(fcolor(white)) saving(attractivity_age, replace);

		drop MV conb conse a upper lower;	
		
	* Interaction Age x Competence
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  age_comp  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	* Marginale Effekte Plot
	
		#delimit ;

		*     ****************************************************************  *;
		*       Generate the values of Z for which you want to calculate the    *;
		*       marginal effect (and standard errors) of X on Y.                *;
		*     ****************************************************************  *;

		generate MV=((_n-33)/1);
		replace  MV=. if _n>65;

		*     ****************************************************************  *;
		*       Grab elements of the coefficient and variance-covariance matrix *;
		*       that are required to calculate the marginal effect and standard *;
		*       errors.                                                         *;
		*     ****************************************************************  *;
		#delimit ;
		reg firstvote2013_dif fp_competence_w age_dif  age_comp fp_attractiveness_w  fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed  doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1;

		matrix b=e(b);
		matrix V=e(V);
 
		scalar b1=b[1,1];
		scalar b2=b[1,2];
		scalar b3=b[1,3];


		scalar varb1=V[1,1];
		scalar varb2=V[2,2];
		scalar varb3=V[3,3];

		scalar covb1b3=V[1,3]; 
		scalar covb2b3=V[2,3];

		scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;



		*     ****************************************************************  *
		*       Calculate the marginal effect of X on Y for all MV values of    *
		*       the modifying variable Z.                                       *
		*     ****************************************************************  *

		#delimit ;
		gen conb=b1+b3*MV if _n<65;


		*     ****************************************************************  *
		*       Calculate the standard errors for the marginal effect of X on Y *
		*       for all MV values of the modifying variable Z.                  *
		*     ****************************************************************  *

		#delimit ;
		gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<65;


		*     ****************************************************************  *
		*       Generate upper and lower bounds of the confidence interval.     *
		*       Specify the significance of the confidence interval.            *
		*     ****************************************************************  *
		#delimit ;

		gen a=1.96*conse;
 
		gen upper=conb+a;
 
		gen lower=conb-a;


		#delimit ;

		*     ****************************************************************  *;
		*       Graph the marginal effect of X on Y across the desired range of *;
		*       the modifying variable Z.  Show the confidence interval.        *;
		*     ****************************************************************  *;

		graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        
             yscale(noline)
             xscale(noline)
             legend(col(1) order(1 2) label(1 "marginal effect competence") 
                                      label(2 "95% ci") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             title("b) Competence", size(4))
             /*subtitle(" " "dependent variable: firstvote difference" " ", size(3))*/
             xtitle( "Age difference" "(winners age minus age of runner up)", size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("marginal effect", size(3))
             scheme(s2mono) graphregion(fcolor(white)) saving(competence_age, replace);

		drop MV conb conse a upper lower;
	
	* Interaction Age x Likability
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  age_lika  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2  incumbency2009_none incumbency2009_both if filter ==1
	* Marginale Effekte Plot
	
		#delimit ;

		*     ****************************************************************  *;
		*       Generate the values of Z for which you want to calculate the    *;
		*       marginal effect (and standard errors) of X on Y.                *;
		*     ****************************************************************  *;

		generate MV=((_n-33)/1);
		replace  MV=. if _n>65;

		*     ****************************************************************  *;
		*       Grab elements of the coefficient and variance-covariance matrix *;
		*       that are required to calculate the marginal effect and standard *;
		*       errors.                                                         *;
		*     ****************************************************************  *;
		#delimit ;
		reg firstvote2013_dif fp_likability_w age_dif  age_lika fp_attractiveness_w  fp_competence_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed  doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2  incumbency2009_none incumbency2009_both if filter ==1;

		matrix b=e(b);
		matrix V=e(V);
 
		scalar b1=b[1,1];
		scalar b2=b[1,2];
		scalar b3=b[1,3];


		scalar varb1=V[1,1];
		scalar varb2=V[2,2];
		scalar varb3=V[3,3];

		scalar covb1b3=V[1,3]; 
		scalar covb2b3=V[2,3];

		scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;



		*     ****************************************************************  *
		*       Calculate the marginal effect of X on Y for all MV values of    *
		*       the modifying variable Z.                                       *
		*     ****************************************************************  *

		#delimit ;
		gen conb=b1+b3*MV if _n<65;


		*     ****************************************************************  *
		*       Calculate the standard errors for the marginal effect of X on Y *
		*       for all MV values of the modifying variable Z.                  *
		*     ****************************************************************  *

		#delimit ;
		gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<65;


		*     ****************************************************************  *
		*       Generate upper and lower bounds of the confidence interval.     *
		*       Specify the significance of the confidence interval.            *
		*     ****************************************************************  *
		#delimit ;

		gen a=1.96*conse;
 
		gen upper=conb+a;
 
		gen lower=conb-a;


		#delimit ;

		*     ****************************************************************  *;
		*       Graph the marginal effect of X on Y across the desired range of *;
		*       the modifying variable Z.  Show the confidence interval.        *;
		*     ****************************************************************  *;

		graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        
             yscale(noline)
             xscale(noline)
             legend(col(1) order(1 2) label(1 "marginal effect likability") 
                                      label(2 "95% ci") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             title("c) Likability", size(4))
             /*subtitle(" " "dependent variable: firstvote difference" " ", size(3))*/
             xtitle( "Age difference" "(winners age minus age of runner up)", size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("marginal effect", size(3))
             scheme(s2mono) graphregion(fcolor(white)) saving(likability_age, replace);

		drop MV conb conse a upper lower;
	
	#delimit cr
	graph combine attractivity_age.gph competence_age.gph likability_age.gph, rows(1) xsize(15) iscale(1)
	graph save figure_5, replace
	
*******************************************************
*******************************************************
**													 **
**	 B) Further statistics reported in the paper	 **
**													 **
*******************************************************
*******************************************************
		
*********************************************
* Ambiguity in the ratings, see footnote 12 *	
*********************************************		
clear all

insheet using "ambiguity.csv", delimiter(",")	

gen mean_clicktime_attr_seconds = meantime_attr/10000000000000
gen mean_clicktime_lika_seconds = meantime_lika/10000000000000
gen mean_clicktime_comp_seconds = meantime_comp/10000000000000

correl freq_nonclicks_attr mean_clicktime_attr_seconds ambivalence_attr
correl freq_nonclicks_lika mean_clicktime_lika_seconds ambivalence_lika
correl freq_nonclicks_comp mean_clicktime_comp_seconds ambivalence_comp 	

*************************************************************************************
* Correlation between weighted scores for attractiveness, likability and competence *	
*************************************************************************************
clear all

insheet using "main_model_data.csv", delimiter(",")	

correl fp_attractiveness_weigh fp_competence_weigh fp_likability_weigh if filter ==1

*******************************************************
*******************************************************
**											         **
**	 C) Figures and Tables from the Online Appendix	 **
**											         **
*******************************************************
*******************************************************
 
****************************************************************************************************
* Appendix O1: Comparison between the appearance ratings of the Freiburg and Passau student raters *	
****************************************************************************************************
clear all
*Read data 
 insheet using "freiburg_passau_comparison.csv", delimiter(",")
 
 replace likability_freiburg = likability_freiburg * 100
 replace likability_passau = likability_passau * 100
 replace competence_freiburg = competence_freiburg * 100
 replace competence_passau = competence_passau * 100
 replace attractiveness_freiburg = attractiveness_freiburg * 100
 replace attractiveness_passau = attractiveness_passau * 100
  
 correl likability_freiburg likability_passau
 correl competence_freiburg competence_passau
 correl attractiveness_freiburg attractiveness_passau
 
 scatter  likability_passau likability_freiburg, name(likability, replace) ///
 ytitle("Percentage of raters in Passau who see" "candidate A as more likable as contestant B")  ///
 xtitle("Percentage of raters in Freiburg who see" "candidate A as more likable as contestant B")
 scatter  competence_passau competence_freiburg, name(competence, replace) ///
 ytitle("Percentage of raters in Passau who see" "candidate A as more likable as contestant B") ///
 xtitle("Percentage of raters in Freiburg who see" "candidate A as more likable as contestant B")
 scatter  attractiveness_passau attractiveness_freiburg ,name(attractiveness, replace) ///
 ytitle("Percentage of raters in Passau who see" "candidate A as more likable as contestant B") ///
 xtitle("Percentage of raters in Freiburg who see" "candidate A as more likable as contestant B")
 
 gr combine likability competence attractiveness, col(3) ysize(3) xsize(12)
 graph save figure_O1, replace
 
**********************************************************
* Appendix O2: Comparison between male and female raters *	
**********************************************************
clear all
*Read data 
	insheet using "for_logit.csv", delimiter(",")			

set more off
ssc install coefplot, replace

* generate dummies + labels 
tab(buttons), gen(button_)

tab(type), gen(type_)
label var type_1  "Frau vs. Frau"
label var type_2  "Mann vs. Mann"
label var type_3  "Frau vor Mann"
label var type_4  "Mann vor Frau"

label define trait 1 "Sympathie" 2 "Kompetenz" 3 "Attraktivitt"
label values trait trait

* Alter in Jahrzehnten
gen alter10 = alter/10

tab clicked buttons if trait ==1, chi2 cchi2 V 

*eindeutige ID pro Rater generieren 
gen id_zusammen = id
replace id_zusammen = id + 1000 if freiburg ==0

* Neue Variable generieren, die den Typ des Wahlkreises angibt 0 = Frau vs Frau, 1 = Mann vs Mann, 2 = Frau vs. Mann
	gen type3 = type_d
	replace type3 = 2 if type_d ==3
	label define type3 0 "Frau vs. Frau" 1 "Mann vs. Mann" 2 "Frau vs. Mann"
	lab val type3 type3
	
* type3 als dummies
tab (type3), gen(type3_) 

* gen Rater-dummies
tab id_zusammen, gen(rater_)

gen kurzhaar_x_sex = 0
replace kurzhaar_x_sex = 1 if kurzhaarfrisur == 1 & sex_cand == 0
 
* 	Freiburg + Passau: split by male and female raters
	
	** Sympathie Modellschtzung 1.1 Haupteffektemodell Frau Rater & Frau vs Frau
	quietly eststo m11a: logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 1 & sex_rater == 0 & type3_1 == 1
	** Kompetenz Modellschtzung 1.1 Haupteffektemodell Frau Rater & Frau vs Frau
	quietly eststo m11b: logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 2 & sex_rater == 0 & type3_1 == 1
	** Attraktivitt Modellschtzung 1.1 Haupteffektemodell Frau Rater & Frau vs Frau
	quietly eststo m11c:logit clicked alter10 brille anzug schmuck kurzhaar_  if trait == 3 & sex_rater == 0 & type3_1 == 1
	
	**Modellschtzung 1.2 Haupteffektemodell Frau Rater & Mann vs Mann
	quietly eststo m12a: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 1 & sex_rater == 0 & type3_2 == 1
	quietly eststo m12b: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 2 & sex_rater == 0 & type3_2 == 1
	quietly eststo m12c: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 3 & sex_rater == 0 & type3_2 == 1
	
	**Modellschtzung 1.3 Haupteffektemodell Frau Rater & Frau vs Mann
	quietly eststo m13a: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 1 & sex_rater == 0 & type3_3 == 1
	quietly eststo m13b: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 2 & sex_rater == 0 & type3_3 == 1
	quietly eststo m13c: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 3 & sex_rater == 0 & type3_3 == 1
	
	**Modellschtzung 1.4 Haupteffektemodell Mann Rater & Frau vs Frau
	quietly eststo m14a: logit clicked alter10 brille anzug schmuck  kurzhaar_ if trait == 1 & sex_rater == 1 & type3_1 == 1
	quietly eststo m14b: logit clicked alter10 brille anzug schmuck  kurzhaar_ if trait == 2 & sex_rater == 1 & type3_1 == 1
	quietly eststo m14c: logit clicked alter10 brille anzug schmuck  kurzhaar_ if trait == 3 & sex_rater == 1 & type3_1 == 1
	
	**Modellschtzung 1.5 Haupteffektemodell Mann Rater & Mann vs Mann
	quietly eststo m15a: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 1 & sex_rater == 1 & type3_2 == 1
	quietly eststo m15b: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 2 & sex_rater == 1 & type3_2 == 1
	quietly eststo m15c: logit clicked alter10 brille anzug  krawatte glatze bart  if trait == 3 & sex_rater == 1 & type3_2 == 1
	
	**Modellschtzung 1.6 Haupteffektemodell Mann Rater & Frau vs Mann
	quietly eststo m16a: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 1 & sex_rater == 1 & type3_3 == 1
	quietly eststo m16b: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 2 & sex_rater == 1 & type3_3 == 1
	quietly eststo m16c: logit clicked sex_cand alter10 brille anzug schmuck krawatte glatze bart kurzhaar_ if trait == 3 & sex_rater == 1 & type3_3 == 1
	
	coefplot(m11c,label(Female rater))(m14c,label(Male rater)),		bylabel("Female vs. Female") ||m12c m15c,	bylabel("Male vs. Male") ||m13c m16c,	bylabel("Female vs. Male") ///
	||m11b m14b,	bylabel("Female vs. Female") ||m12b m15b,	bylabel("Male vs. Male") ||m13b m16b,	bylabel("Female vs. Male") ///
	||m11a m14a,	bylabel("Female vs. Female") ||m12a m15a,	bylabel("Male vs. Male") ||m13a m16a,	bylabel("Female vs. Male")||	,eform xline(1, lcolor(black) lpattern(dot)) xtitle(Odds Ratio mit 99% Konfidenzintervallen) byopts(xrescale)  ///
	ylab( ,labs (small) ) lev(99) drop(_cons) omitted baselevels coeflab(alter10="Age (in decades)" brille="Glasses" anzug="Suit/Blazer" ///
	schmuck="Jewelry" kurzhaar_x_sex="Short hairstyle for women" krawatte ="Tie" glatze="Bald head" bart="Beard" sex_candidate="Sex (M = 1, F = 0)") grid(none) ciopts(lwidth(*3) lcolor(*.6)) legend(row(1))	
		
graph save figure_O2, replace 					


**********************************************************
* Appendix O3: Variable overview 						 *	
**********************************************************
clear all

insheet using "main_model_data.csv", delimiter(",")	

gen percent_pop_male = 100*(pop_male/pop)
replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */
sum firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w attractiveness_w competence_w likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man woman_vs_woman contested secondvote2013_dif  incumbencydirect_cand1 incumbencydirect_cand2 incumbencydirect_none incumbency2009_cand1 incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1


************************************************************
* Appendix O4: Main models with influential cases excluded *	
************************************************************
clear all

set more off
insheet using "main_model_data.csv", delimiter(",")	

gen percent_pop_male = 100*(pop_male/pop)
replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */

* model 1
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1
predict DFITS, dfits
gen absDFITS = abs(DFITS)
list DFITS districtname_2013 if filter ==1 & absDFITS > 2*sqrt((18+1)/259)
drop DFITS absDFITS
predict cooksd, cooksd
list cooksd if cooksd >4/259
gen cooksd_dummy = 0
replace cooksd_dummy = 1 if cooksd > 4/259
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1 & cooksd_dummy ==0, robust
est store main_model1_cook
drop cooksd 
drop cooksd_dummy

* model 2
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1
predict DFITS, dfits
gen absDFITS = abs(DFITS)
list DFITS districtname_2013 if filter ==1 & absDFITS > 2*sqrt((18+1)/259)
drop DFITS absDFITS
predict cooksd, cooksd
list cooksd if cooksd >4/259
gen cooksd_dummy = 0
replace cooksd_dummy = 1 if cooksd > 4/259
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1 & cooksd_dummy ==0
est store main_model2_cook
drop cooksd 
drop cooksd_dummy

* model 3
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1
predict DFITS, dfits
gen absDFITS = abs(DFITS)
list DFITS districtname_2013 if filter ==1 & absDFITS > 2*sqrt((18+1)/259)
drop DFITS absDFITS
predict cooksd, cooksd
list cooksd if cooksd >4/259
gen cooksd_dummy = 0
replace cooksd_dummy = 1 if cooksd > 4/259
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1 & cooksd_dummy ==0, robust
est store stepwise1_cook
drop cooksd 
drop cooksd_dummy

* model 4
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1
predict DFITS, dfits
gen absDFITS = abs(DFITS)
list DFITS districtname_2013 if filter ==1 & absDFITS > 2*sqrt((18+1)/259)
drop DFITS absDFITS
predict cooksd, cooksd
list cooksd if cooksd >4/259
gen cooksd_dummy = 0
replace cooksd_dummy = 1 if cooksd > 4/259
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1 & cooksd_dummy==0
est store stepwise2_cook
drop cooksd 
drop cooksd_dummy

outreg2 [ main_model2_cook stepwise2_cook main_model1_cook  stepwise1_cook] using table_O4, word replace		


**********************************************************
* Appendix O5: Main models with betas					 *	
**********************************************************

clear all

set more off
insheet using "main_model_data.csv", delimiter(",")	

gen percent_pop_male = 100*(pop_male/pop)
replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */

regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1, beta
est store main_model2_beta
regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1, beta
est store main_model1_beta
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbencydirect_cand2 incumbencydirect_none if filter ==1, beta
est store stepwise1_beta
stepwise, pr(.10):regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor man_vs_man man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_both incumbency2009_none if filter ==1, robust beta
est store stepwise2_beta
outreg2 [ main_model2_beta stepwise2_beta main_model1_beta  stepwise1_beta] using table_O5, beta word replace

**********************************************************
* Appendix O6: Interaction models						 *	
**********************************************************

clear all

set more off
insheet using "main_model_data.csv", delimiter(",")	

gen percent_pop_male = 100*(pop_male/pop)
replace businesstax = businesstax/1000 /* Gewerbesteuer in 1000 Euro pro Einwohner */

* Interaction incumbency_BT x attractiveness
	gen incumbency_BT1_attr = incumbency2009_cand1 * fp_attractiveness_w
	gen incumbency_BT2_attr = incumbency2009_cand2 * fp_attractiveness_w
	gen incumbency_BTnone_attr = incumbency2009_none * fp_attractiveness_w
	gen incumbency_BTboth_attr = incumbency2009_both * fp_attractiveness_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  incumbency_BT2_attr incumbency_BTnone_attr incumbency_BTboth_attr businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store incumbency_BT1
	
* Interaction incumbency_BT x competence
	gen incumbency_BT1_comp = incumbency2009_cand1 * fp_competence_w
	gen incumbency_BT2_comp = incumbency2009_cand2 * fp_competence_w
	gen incumbency_BTnone_comp = incumbency2009_none * fp_competence_w
	gen incumbency_BTboth_comp = incumbency2009_both * fp_competence_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  incumbency_BT2_comp incumbency_BTnone_comp incumbency_BTboth_comp businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store incumbency_BT2
	
* Interaction incumbency_BT x likability
	gen incumbency_BT1_lika = incumbency2009_cand1 * fp_likability_w
	gen incumbency_BT2_lika = incumbency2009_cand2 * fp_likability_w
	gen incumbency_BTnone_lika = incumbency2009_none * fp_likability_w
	gen incumbency_BTboth_lika = incumbency2009_both * fp_likability_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  incumbency_BT2_lika incumbency_BTnone_lika incumbency_BTboth_lika businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store incumbency_BT3

* Interactions attractiveness x gender district dummies 
	gen man_man_attr = man_vs_man * fp_attractiveness_w
	gen woman_woman_attr = woman_vs_woman * fp_attractiveness_w
	gen man_woman_attr = man_vs_woman * fp_attractiveness_w
	gen woman_man_attr = woman_vs_man * fp_attractiveness_w

	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w woman_woman_attr  man_woman_attr woman_man_attr businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store gender1 

* Interactions competence x gender 
	gen man_man_comp = man_vs_man * fp_competence_w
	gen woman_woman_comp = woman_vs_woman * fp_competence_w
	gen man_woman_comp = man_vs_woman * fp_competence_w
	gen woman_man_comp = woman_vs_man * fp_competence_w

	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  woman_woman_comp  man_woman_comp woman_man_comp businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store gender2

* Interactions likability x gender 
	gen man_man_lika = man_vs_man * fp_likability_w
	gen woman_woman_lika = woman_vs_woman * fp_likability_w
	gen man_woman_lika = man_vs_woman * fp_likability_w
	gen woman_man_lika = woman_vs_man * fp_likability_w

	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  woman_woman_lika  man_woman_lika woman_man_lika businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store gender3

* Interaction Age x Attractiveness
	gen age_attr = age_dif * fp_attractiveness_w
	
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w  fp_likability_w age_attr  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store age1	
	
* Interaction Age x Competence
	gen age_comp = age_dif * fp_competence_w
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  age_comp  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2 incumbency2009_none incumbency2009_both if filter ==1
	est store age2	
	
* Interaction Age x Likability
	gen age_lika = age_dif * fp_likability_w
	regress firstvote2013_dif fp_attractiveness_w fp_competence_w fp_likability_w  age_lika  businesstax business_reg turnout percent_pop_male senior_youth  unemployed age_dif doctor woman_vs_woman man_vs_woman woman_vs_man contested secondvote2013_dif  incumbency2009_cand2  incumbency2009_none incumbency2009_both if filter ==1
	est store age3	
	
outreg2 [incumbency_BT1 incumbency_BT2 incumbency_BT3 gender1 gender2 gender3 age1 age2 age3] using table_O6,  word replace


